@@ -21,8 +21,7 @@
 #include "freebusyganttproxymodel.h"
 #include "CalendarSupport/FreeBusyItemModel"
 
-#include <KDGantt2/KDGanttGraphicsView>
-
+#include <KGantt/KGanttGraphicsView>
 #include <KCalCore/FreeBusyPeriod>
 
 #include <KLocalizedString>
@@ -47,8 +46,8 @@ QVariant FreeBusyGanttProxyModel::data(const QModelIndex &index, int role) const
     // if the index is not valid, then its a toplevel item, which is an attendee
     if (!source_index.parent().isValid()) {
         switch (role) {
-        case KDGantt::ItemTypeRole:
-            return KDGantt::TypeMulti;
+        case KGantt::ItemTypeRole:
+            return KGantt::TypeMulti;
         case Qt::DisplayRole:
             return source_index.data(Qt::DisplayRole);
         default:
@@ -59,15 +58,15 @@ QVariant FreeBusyGanttProxyModel::data(const QModelIndex &index, int role) const
     // if the index is valid, then it corrsponds to a free busy period
     KDateTime::Spec timeSpec = KSystemTimeZones::local();
     KCalCore::FreeBusyPeriod period =
-        sourceModel()->data(source_index, KPIM::FreeBusyItemModel::FreeBusyPeriodRole).
+        sourceModel()->data(source_index, CalendarSupport::FreeBusyItemModel::FreeBusyPeriodRole).
         value<KCalCore::FreeBusyPeriod>();
 
     switch (role) {
-    case KDGantt::ItemTypeRole:
-        return KDGantt::TypeTask;
-    case KDGantt::StartTimeRole:
+    case KGantt::ItemTypeRole:
+        return KGantt::TypeTask;
+    case KGantt::StartTimeRole:
         return period.start().toTimeSpec(timeSpec).dateTime();
-    case KDGantt::EndTimeRole:
+    case KGantt::EndTimeRole:
         return period.end().toTimeSpec(timeSpec).dateTime();
     case Qt::BackgroundRole:
         return QColor(Qt::red);
@@ -84,25 +83,25 @@ QString FreeBusyGanttProxyModel::tooltipify(const KCalCore::FreeBusyPeriod &peri
         const KDateTime::Spec &timeSpec) const
 {
     QString toolTip = QStringLiteral("<qt>");
-    toolTip += "<b>" + i18nc("@info:tooltip", "Free/Busy Period") + "</b>";
-    toolTip += QLatin1String("<hr>");
+    toolTip += QStringLiteral("<b>") + i18nc("@info:tooltip", "Free/Busy Period") + QStringLiteral("</b>");
+    toolTip += QStringLiteral("<hr>");
     if (!period.summary().isEmpty()) {
-        toolTip += "<i>" + i18nc("@info:tooltip", "Summary:") + "</i>" + "&nbsp;";
+        toolTip += QStringLiteral("<i>") + i18nc("@info:tooltip", "Summary:") + QStringLiteral("</i>") + QStringLiteral("&nbsp;");
         toolTip += period.summary();
-        toolTip += QLatin1String("<br>");
+        toolTip += QStringLiteral("<br>");
     }
     if (!period.location().isEmpty()) {
-        toolTip += "<i>" + i18nc("@info:tooltip", "Location:") + "</i>" + "&nbsp;";
+        toolTip += QStringLiteral("<i>") + i18nc("@info:tooltip", "Location:") + QStringLiteral("</i>") + QStringLiteral("&nbsp;");
         toolTip += period.location();
-        toolTip += QLatin1String("<br>");
+        toolTip += QStringLiteral("<br>");
     }
-    toolTip += "<i>" + i18nc("@info:tooltip period start time", "Start:") + "</i>" + "&nbsp;";
+    toolTip += QStringLiteral("<i>") + i18nc("@info:tooltip period start time", "Start:") + QStringLiteral("</i>") + QStringLiteral("&nbsp;");
     toolTip += QLocale::system().toString(period.start().toTimeSpec(timeSpec).dateTime(), QLocale::ShortFormat);
-    toolTip += QLatin1String("<br>");
-    toolTip += "<i>" + i18nc("@info:tooltip period end time", "End:") + "</i>" + "&nbsp;";
+    toolTip += QStringLiteral("<br>");
+    toolTip += QStringLiteral("<i>") + i18nc("@info:tooltip period end time", "End:") + QStringLiteral("</i>") + QStringLiteral("&nbsp;");
     toolTip += QLocale::system().toString(period.end().toTimeSpec(timeSpec).dateTime(), QLocale::ShortFormat);
-    toolTip += QLatin1String("<br>");
-    toolTip += QLatin1String("</qt>");
+    toolTip += QStringLiteral("<br>");
+    toolTip += QStringLiteral("</qt>");
     return toolTip;
 }
 
